@@ -1,7 +1,9 @@
 #!/bin/sh
 # savecpu
-# versione 2.20 by m750 at smartphonetab.net
+# versione 2.21 by m750 at smartphonetab.net
 # lettura conf da file
+# patch for v50 by peter leinchen
+
 
 if [ `id -u` != 0 ] ; then
     exec root <<EOF
@@ -49,7 +51,7 @@ accendi_led=0
 # imposta il valore, espresso in secondi, tra una verifica e l'altra
 #intervallo=10
 
-# imposta intensit LED, sconsiglio di superare il valore 20
+# imposta intensità LED, sconsiglio di superare il valore 20
 ledi=18
 
 #imposta colore LED: $verde o $rosso o $blu
@@ -79,13 +81,15 @@ sleep 2
 
 while [ $start == 1 ]
 do
-  #echo "riduci : " $riduci
-  #echo "led : " $accendi_led
+  #echo "riduci è: " $riduci
+  #echo "led è: " $accendi_led
   #echo $minima
   #echo $massima
   #temperatura=`cat /sys/class/power_supply/bq27200-0/temp`
-  temperatura=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1+7}'`
-  #echo "temp: " $temperatura
+  ###temperatura=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1+7}'`
+  temperatura=`echo $(i2cget -y 2 0x55 0x06 w) | awk '{ printf ($1*0.25-273)*100 }'`
+  temperatura=`expr \( $temperatura + 50 \) \/ 100`
+  echo "temp: " $temperatura
 
 # v47
 #  lunghezza=${#temperatura}
@@ -109,7 +113,7 @@ do
        massima=$(/usr/sbin/kernel-config show | grep 'max.' | tr '\n' ' ' | awk '{print $3}') 
        if [ 650 -le $massima ]
        then
-         /usr/sbin/kernel-config limits 250 600
+         /usr/sbin/kernel-config limits - 600
          dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:"savecpu: temp. >= "$temperatura_max" degrees centigrade - downgrade overclock" uint32:0 string:"OK"
          echo "RIDUCO"
        fi
@@ -149,7 +153,7 @@ do
       then
           echo "RIPRISTINO"
           /usr/sbin/kernel-config limits $minima $massima
-          #echo "riduci : " $riduci
+          #echo "riduci è: " $riduci
           riduci=0
           #echo "SPENGO LED"
           accendi_led=0
@@ -193,6 +197,8 @@ exit 0
 
 
 
+#
+
 #
 
 #
